<?php

/**
 * Copyright 2017 MICRORISC s.r.o.
 * Copyright 2017-2019 IQRF Tech s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
declare(strict_types = 1);

namespace App\GatewayModule\Presenters;

use App\CoreModule\Presenters\ProtectedPresenter;
use App\CoreModule\Traits\TPresenterFlashMessage;
use App\GatewayModule\Models\PowerManager;

/**
 * IQRF Gateway Daemon's power manager presenter
 */
class PowerPresenter extends ProtectedPresenter {

	use TPresenterFlashMessage;

	/**
	 * @var PowerManager IQRF Gateway Daemon's power manager
	 */
	private $manager;

	/**
	 * Constructor
	 * @param PowerManager $manager IQRF Gateway Daemon's power manager
	 */
	public function __construct(PowerManager $manager) {
		$this->manager = $manager;
		parent::__construct();
	}

	/**
	 * Powers off IQRF Gateway
	 */
	public function handleOff(): void {
		if ($this->isAjax()) {
			$this->flashSuccess('gateway.power.powerOff.success');
			$this->manager->powerOff();
		}
	}

	/**
	 * Reboots IQRF Gateway
	 */
	public function handleReboot(): void {
		if ($this->isAjax()) {
			$this->flashSuccess('gateway.power.reboot.success');
			$this->manager->reboot();
		}
	}

}
